/* Startup code needed by GCC C++ output code.  */
/* Copyright (C) 1991 Free Software Foundation, Inc.

This file is part of GNU CC.

GNU CC is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU CC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU CC; see the file COPYING.  If not, write to
the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.  */

/* As a special exception, if you link this file with files
   compiled with GCC to produce an executable, this does not cause
   the resulting executable to be covered by the GNU General Public License.
   This exception does not however invalidate any other reasons why
   the executable file might be covered by the GNU General Public License.  */

/*  init_main.h: Originally developed by James Kempf for SUN,
 *               adapted and commented for FSF by Heinz Seidl (hgs@cygnus.com)
 */

#ifndef _INIT_MAIN_H
#define _INIT_MAIN_H

/* That's the type of the entry point for initialization and finalization */

typedef void entry_pt();

/* Type of __C/DTOR_LIST__[] */

typedef entry_pt * ep_fp;

/* The default name of the initialization function(s). */

#define INITIALIZE_MODULE      __init           /* one less _ due to assembler */
#define FINALIZE_MODULE        __fini
#define INITIALIZE_MODULE_NAME "___init"
#define FINALIZE_MODULE_NAME   "___finit"
#define INIT_START             __init_start
#define INIT_END               __init_end

#endif /* !_INIT_MAIN_H */
